import React from 'react'
import Calendar from 'react-calendar/dist/entry.nostyle'

import PropTypes from 'prop-types';
import moment from 'moment'

class DateTimePicker extends React.Component {

  constructor(props) {
    super(props)

    this.setTime = this.setTime.bind(this)
    this.setDate = this.setDate.bind(this)
  }

  setDate(value) {
    this.props.getDateCalendar(moment(value).format('YYYY-MM-DD'), this.props.id)
    this.setState({
      selectedDate: value,
      showCalendar: false,
    })
  }

  setTime(event) {
    this.props.getTimeCalendar(event.target.value, this.props.id)
    this.setState({
      selectedTime: event.target.value,
    });
  }

  static getDerivedStateFromProps(nextProps, prevState) {
    if(prevState && (nextProps.selectedTime !== prevState.selectedTime || nextProps.selectedDate !== prevState.selectedDate)) {
      return {
        selectedTime: prevState.selectedTime,
        selectedDate: new Date(prevState.selectedDate),
      }
    }
    return {
      selectedTime: nextProps.selectedTime,
      selectedDate: new Date(nextProps.selectedDate),
    }
  }

  componentDidMount() {
    this.props.getDateCalendar(moment(this.state.selectedDate).format('YYYY-MM-DD'), this.props.id)
    this.props.getTimeCalendar(this.state.selectedTime, this.props.id)
  }

  render() {
    return (
      <div className="picker">
        {this.props.title &&
          <div className="picker__title">
            {this.props.title}
          </div>
        }
        <div className="picker__content">
          <div className="picker__content__calendar">
            <Calendar
              activeStartDate={new Date()}
              minDate={new Date()}
              minDetail="month"
              nextLabel=""
              prevLabel=""
              value={this.state.selectedDate}
              onChange={this.setDate}
            />
          </div>
          {!this.props.hideTime &&
            <div className="picker__content__time">
              <i className={'fa fa-info-circle'}></i>
              {this.props.label &&
                <label htmlFor="picker__content__time__label">
                  {this.props.label}
                </label>
              }
              <div className="select-menu picker__content__select-menu">
                <select name="entry-time" value={this.state.selectedTime} onChange={this.setTime}>
                  <option>00:00</option>
                  <option>01:00</option>
                  <option>02:00</option>
                  <option>03:00</option>
                  <option>04:00</option>
                  <option>05:00</option>
                  <option>06:00</option>
                  <option>07:00</option>
                  <option>08:00</option>
                  <option>09:00</option>
                  <option>10:00</option>
                  <option>11:00</option>
                  <option>12:00</option>
                  <option>13:00</option>
                  <option>14:00</option>
                  <option>15:00</option>
                  <option>16:00</option>
                  <option>17:00</option>
                  <option>18:00</option>
                  <option>19:00</option>
                  <option>20:00</option>
                  <option>21:00</option>
                  <option>22:00</option>
                  <option>23:00</option>
                </select>
              </div>
            </div>
          }
        </div>
      </div>
    )
  }
}

export default DateTimePicker;
