import React from 'react'
import {
  Link,
} from 'react-router-dom';

import PropTypes from 'prop-types';

class Header extends React.Component {
  constructor(props) {
    super(props)

    this.state = {
      toggleMenu: false,
    }

    this.mobileMenuClick = this.mobileMenuClick.bind(this);
    this.closeMenu = this.closeMenu.bind(this);
  }
  componentWillMount() {
    this.setState({
      menuLinks: this.props.menuLinks,
      match: this.props.match,
      title: this.props.title,
      logoUrl: this.props.logoUrl,
    })
  }
  componentWillReceiveProps(newProps) {
    this.setState({
      menuLinks: newProps.menuLinks,
      match: newProps.match,
      title: newProps.title,
      logoUrl: newProps.logoUrl,
    })
  }

  mobileMenuClick(event) {
    const toggleMenu = this.state.toggleMenu = !this.state.toggleMenu

    this.setState({
      toggleMenu,
    })

    event.preventDefault()
  }

  closeMenu() {
    this.setState({
      toggleMenu: false,
    })
  }

  render() {
    return (
      <div className={this.state.title ? 'header header--title' : 'header'}>
        <div className="header__logo">
          <Link to="/">
            <img className="img-fluid" alt="Edinburgh Airport" src={this.state.logoUrl}/>
          </Link>
        </div>

        {this.state.menuLinks &&
          <div style={{display: 'inline',}}>
            <div className="d-block d-md-none d-lg-none">
              <a href="" className="header__menuBurger" onClick={this.mobileMenuClick}><i className="fa fa-bars"></i></a>

              {this.state.toggleMenu &&
                  <div className="header__links">
                    <div className="header__links__coverbackground" onClick={this.closeMenu}></div>
                    <div className="header__links__background">
                      <ul>
                        {this.state.menuLinks.map((item, key) => {
                          return (<li key={key}>
                            <Link to={item.url} onClick={this.closeMenu}>
                              {item.name}
                            </Link>
                          </li>)
                        })}
                      </ul>
                    </div>
                  </div>
              }
            </div>

            <div className="header__links d-none d-md-inline-block d-lg-inline-block">
              <ul>
                {this.state.menuLinks.map((item, key) => {
                  return (<li key={key}  style={this.state.match.path === item.url ? {borderBottom: '8px white solid',} : {}}>
                    <Link to={item.url}>
                      {item.name}
                    </Link>
                  </li>)
                })}
              </ul>
            </div>
          </div>
        }
        {this.state.title && <div className="header__title">
          {this.props.children}
        </div>}
      </div>
    )
  }
}


export default Header;

Header.propTypes = {

}
